@@ -1,7 +1,7 @@
-use strum_macros::EnumString;
+use strum_macros::{Display, EnumString};
 
 /// The mode of calculation to use on the range of Commits to calculate the next semantic version.
-#[derive(Debug, EnumString)]
+#[derive(Debug, PartialEq, Eq, Clone, Copy, Display, EnumString)]
 pub enum CalculationMode {
     /// In batch mode the largest Semantic Versioning increment determined by the Conventional
     /// Commits type across all the commits is the only increment applied.
